pub struct LogSinkWaitForInterestChangeResponse {
pub data: Interest,
}Fields
data: InterestTrait Implementations
Sourceimpl CompatFrom<LogSinkWaitForInterestChangeResponse> for LogSinkWaitForInterestChangeResponse
impl CompatFrom<LogSinkWaitForInterestChangeResponse> for LogSinkWaitForInterestChangeResponse
Sourcefn compat_from(
value: LogSinkWaitForInterestChangeResponse,
) -> LogSinkWaitForInterestChangeResponse
fn compat_from( value: LogSinkWaitForInterestChangeResponse, ) -> LogSinkWaitForInterestChangeResponse
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<LogSinkWaitForInterestChangeResponse<'static>, ___E> for &'a LogSinkWaitForInterestChangeResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<LogSinkWaitForInterestChangeResponse<'static>, ___E> for &'a LogSinkWaitForInterestChangeResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<LogSinkWaitForInterestChangeResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<LogSinkWaitForInterestChangeResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<LogSinkWaitForInterestChangeResponse<'static>, ___E> for LogSinkWaitForInterestChangeResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<LogSinkWaitForInterestChangeResponse<'static>, ___E> for LogSinkWaitForInterestChangeResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<LogSinkWaitForInterestChangeResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<LogSinkWaitForInterestChangeResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, LogSinkWaitForInterestChangeResponse<'static>>, ___E> for &'a LogSinkWaitForInterestChangeResponsewhere
___E: Encoder + ?Sized,
&'a LogSinkWaitForInterestChangeResponse: Encode<LogSinkWaitForInterestChangeResponse<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, LogSinkWaitForInterestChangeResponse<'static>>, ___E> for &'a LogSinkWaitForInterestChangeResponsewhere
___E: Encoder + ?Sized,
&'a LogSinkWaitForInterestChangeResponse: Encode<LogSinkWaitForInterestChangeResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a LogSinkWaitForInterestChangeResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, LogSinkWaitForInterestChangeResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a LogSinkWaitForInterestChangeResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, LogSinkWaitForInterestChangeResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, LogSinkWaitForInterestChangeResponse<'static>>, ___E> for LogSinkWaitForInterestChangeResponsewhere
___E: Encoder + ?Sized,
LogSinkWaitForInterestChangeResponse: Encode<LogSinkWaitForInterestChangeResponse<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, LogSinkWaitForInterestChangeResponse<'static>>, ___E> for LogSinkWaitForInterestChangeResponsewhere
___E: Encoder + ?Sized,
LogSinkWaitForInterestChangeResponse: Encode<LogSinkWaitForInterestChangeResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<LogSinkWaitForInterestChangeResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, LogSinkWaitForInterestChangeResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<LogSinkWaitForInterestChangeResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, LogSinkWaitForInterestChangeResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<LogSinkWaitForInterestChangeResponse<'de>> for LogSinkWaitForInterestChangeResponse
impl<'de> FromWire<LogSinkWaitForInterestChangeResponse<'de>> for LogSinkWaitForInterestChangeResponse
Sourcefn from_wire(
wire: LogSinkWaitForInterestChangeResponse<'de>,
) -> LogSinkWaitForInterestChangeResponse
fn from_wire( wire: LogSinkWaitForInterestChangeResponse<'de>, ) -> LogSinkWaitForInterestChangeResponse
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<LogSinkWaitForInterestChangeResponse<'de>> for LogSinkWaitForInterestChangeResponse
impl<'de> FromWireRef<LogSinkWaitForInterestChangeResponse<'de>> for LogSinkWaitForInterestChangeResponse
Sourcefn from_wire_ref(
wire: &LogSinkWaitForInterestChangeResponse<'de>,
) -> LogSinkWaitForInterestChangeResponse
fn from_wire_ref( wire: &LogSinkWaitForInterestChangeResponse<'de>, ) -> LogSinkWaitForInterestChangeResponse
Converts the given reference to this type.
Sourceimpl PartialEq for LogSinkWaitForInterestChangeResponse
impl PartialEq for LogSinkWaitForInterestChangeResponse
Sourcefn eq(&self, other: &LogSinkWaitForInterestChangeResponse) -> bool
fn eq(&self, other: &LogSinkWaitForInterestChangeResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for LogSinkWaitForInterestChangeResponse