LogSinkLocalServerHandler

Trait LogSinkLocalServerHandler 

pub trait LogSinkLocalServerHandler<___T: Transport = Channel> {
    // Required methods
    fn wait_for_interest_change(
        &mut self,
        responder: Responder<WaitForInterestChange, ___T>,
    ) -> impl Future<Output = ()>;
    fn connect_structured(
        &mut self,
        request: Request<ConnectStructured, ___T>,
    ) -> impl Future<Output = ()>;

    // Provided method
    fn on_unknown_interaction(
        &mut self,
        ordinal: u64,
    ) -> impl Future<Output = ()> { ... }
}
A server handler for the LogSink protocol.

See LogSink for more details.

Required Methods

fn wait_for_interest_change( &mut self, responder: Responder<WaitForInterestChange, ___T>, ) -> impl Future<Output = ()>

LogSink implementers will return to this hanging-get whenever the scope of their interest changes. Clients are expected to emit messages based on the registered Interest. In the event that an empty interest is conveyed, clients should emit messages based on their default e.g. compile time configuration. Each client may only poll this once at a time. Invoking WaitForInterestChange a second time before the first call returns will result in an error being returned.

fn connect_structured( &mut self, request: Request<ConnectStructured, ___T>, ) -> impl Future<Output = ()>

Send this socket to be drained, using the structured logs format.

See Encoding structured records for what is expected to be received over the socket.

Provided Methods

fn on_unknown_interaction(&mut self, ordinal: u64) -> impl Future<Output = ()>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<___H, ___T> LogSinkLocalServerHandler<___T> for Local<___H>
where ___H: LogSinkServerHandler<___T>, ___T: Transport,

Source

async fn wait_for_interest_change( &mut self, responder: Responder<WaitForInterestChange, ___T>, )

Source

async fn connect_structured( &mut self, request: Request<ConnectStructured, ___T>, )

Source

async fn on_unknown_interaction(&mut self, ordinal: u64)

Implementors